@@ -90,9 +90,9 @@ class LearningMachine(object):
                d2Etole=0.05,
                dEstop=1.0,
                nn=True,vdwnn=False,
-               bo_layer=[4,1],
-               bf_layer=[9,2],
-               be_layer=[9,2],
+               bo_layer=[2,1],
+               bf_layer=[6,1],
+               be_layer=[6,1],
                EnergyFunction=3,
                MessageFunction=1,
                bom={'others':1.0},
@@ -160,13 +160,12 @@ class LearningMachine(object):
       self.EnergyFunction = EnergyFunction
       self.MessageFunction= MessageFunction
       self.FreeAtoms    = FreeAtoms
-      
-      self.c = AtomDance(poscar=self.initConfig,nn=self.nn,
-                         rtole=self.rtole,bondTole=self.bondTole)
-      self.natom     = self.c.natom
-      self.atom_name = self.c.atom_name
+      self.c            = AtomDance(poscar=self.initConfig,nn=self.nn,
+                                    rtole=self.rtole-0.05,bondTole=self.bondTole)
+      self.natom        = self.c.natom
+      self.atom_name    = self.c.atom_name
       self.get_ro(rodic)
-      
+
       if self.mpopt==1:
          self.messages  = 1
       elif self.mpopt==2 or self.mpopt==3:
@@ -239,20 +238,24 @@ class LearningMachine(object):
           else:
              atoms = read(self.initConfig)
              atoms = self.c.bond_momenta_bigest(atoms)
-             e_gmd,mdsteps = self.mlmd(cwd,run_dir,atoms,100000,i,learnWay) 
+             e_gmd,mdsteps = self.mlmd(cwd,run_dir,atoms,10000,i,learnWay) 
  
           if learnWay==4 and lw4:
              atoms,lw4 = self.c.bond_momenta(atoms)
           else:
              bondBroken,bkbd = self.c.check_bond(atoms=atoms,bondTole=self.bondTole)
-          if not lw4: learnWay = 3                                     
+          if not lw4: learnWay = 3   
+
           if bondBroken>=1 and self.CheckBond and (not bkbd is None):  # if bonds have broken
              mdsteps = 10
              images = self.c.stretch(bkbd,atoms=atoms,nbin=mdsteps,st=self.bondTole-0.015,ed=1.0,scale=1.2,traj='md.traj')
              if images is None:
                 atoms = self.c.bond_momenta_bigest(atoms)
-                e_gmd,mdsteps = self.mlmd(cwd,run_dir,atoms,100000,i,learnWay) 
-     
+                e_gmd,mdsteps = self.mlmd(cwd,run_dir,atoms,10000,i,learnWay) 
+             else:
+                atoms  = images[-1]
+                bondBroken,bkbd = self.c.check_bond(atoms=atoms,bondTole=self.bondTole)
+
           atoms.write('poscar.gen')                                    # for aimd
           if learnWay>=3: 
              dft_step = int(mdsteps/self.colFrame)+1
@@ -268,7 +271,7 @@ class LearningMachine(object):
           with open('training.log','w') as fe:                         # 
                fe.write('## training loss and accuries\n')             #
           trajs_.update(self.direcs)                                   #
-          
+
           self.load_config()
           tf.compat.v1.disable_eager_execution()                       # training untill
           accu = -1000.0                                               # acc >= accMin
@@ -304,7 +307,8 @@ class LearningMachine(object):
 
           self.lossCriteria = float(loss)
 
-          e_gmd,mdsteps = self.mlmd(cwd,run_dir,atoms,100000,i,learnWay) 
+          if bondBroken<1 or (not self.CheckBond): 
+             e_gmd,mdsteps = self.mlmd(cwd,run_dir,atoms,10000,i,learnWay) 
           step += mdsteps                                          # run ML-MD test training results     
 
           if accu >= self.accCriteria and tstep<self.step and tIter<=2: # get md steps
@@ -335,10 +339,9 @@ class LearningMachine(object):
          #              fe.write(' %d %f %f diff: %f \n' %(step+i_,e_gmd[i_],e_aimd[0],diff))
          #           else:                                              #
          #              fe.write(' %d %f \n' %(step+i_,e_gmd[i_]))      #
-
           self.learninglog(i,loss,accu,mdsteps,e_gulp[-1],e_siesta[-1],dEmax_,d2Emax_,learnWay,
                            bondBroken,bkbd)
-          
+
           converg_ = converg
           if diff<=self.convergence: 
              converg = True
@@ -378,6 +381,7 @@ class LearningMachine(object):
             l.write('Bond between atoms %d and %d was broken during MLMD.\n' %(bkbd[0],bkbd[1]))
          l.write(' \n')
 
+
   def aimd(self,cwd,run_dir,tstep,gen,learnWay):
       mkdir(run_dir)
       chdir(cwd+'/'+run_dir)
