@@ -145,17 +145,17 @@ def train_mpnn(direcs=None,step=5000,batch=None,convergence=0.97,lossConvergence
     else:
        ffd = 'ffield_' + str(libstep) + '.json'
 
+    p   = rn.p_
     if loss==0.0 and accu==0.0:
        # send_msg('-  Warning: the loss is NaN, parameters from %s changed auomatically ...' %ffd)
-       with open(ffd,'r') as fj:
-            j = js.load(fj)
-            ic = Init_Check(nanv=nanv)
-            j['p'] = ic.auto(j['p'])
-            ic.close()
-       with open('ffield.json','w') as fj:
-            js.dump(j,fj,sort_keys=True,indent=2)
-
-    p   = rn.p_
+       # with open(ffd,'r') as fj:
+       #      j = js.load(fj)
+       #      ic = Init_Check(nanv=nanv)
+       #      j['p'] = ic.auto(j['p'])
+       #      ic.close()
+       # with open('ffield.json','w') as fj:
+       #      js.dump(j,fj,sort_keys=True,indent=2)
+       return loss,accu,accMax,p,zpe,i
 
     rn.close()
     return loss,accu,accMax,p,zpe,i
